@@ -23,6 +23,10 @@ def run_cmd(cmd: list[str]):
         pty.spawn(cmd, lambda fd: os.read(fd, 1024))
 
 
-def raise_error(txt):
-    typer.echo(typer.style(txt, fg="red"), err=txt)
+def raise_error(txt: str):
+    typer.echo(typer.style("Error: " + txt, fg="red"), err=txt)
     raise typer.Exit(1)
+
+
+def warn(txt: str):
+    typer.echo(typer.style("Warning: " + txt, fg="yellow"))
